@@ -1,10 +1,10 @@
 import os
 import warnings
 
-import matplotlib.pyplot as plt
 import matplotlib as mpl
+import matplotlib.pyplot as plt
 
-from .dims import set_dim, GOLDEN_SLIDE
+from .dims import GOLDEN_SLIDE, set_dim
 
 filepath = os.path.dirname(os.path.abspath(__file__))
 
@@ -42,7 +42,6 @@ def _format(
     for ax in axes:
         if ax.get_title() == "":
             warnings.warn("Title is not specified!")
-
         if ax.get_xlabel() == "":
             warnings.warn("X-axis label not specified!")
         if ax.get_ylabel() == "":
